==> apache-beam-2.63.0-source-release.zip: beam-2.63.0/sdks/java/core/src/main/java/org/apache/beam/sdk/metrics/DelegatingGauge.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.metrics;

import java.io.Serializable;
import org.apache.beam.sdk.annotations.Internal;

/** Implementation of {@link Gauge} that delegates to the instance for the current context. */
@Internal
public class DelegatingGauge implements Metric, Gauge, Serializable {
  private final MetricName name;
  private final boolean processWideContainer;
  private final boolean perWorkerGauge;

  /**
   * Create a {@code DelegatingGauge} with {@code perWorkerGauge} and {@code processWideContainer}
   * set to false.
   *
   * @param name Metric name for this metric.
   */
  public DelegatingGauge(MetricName name) {
    this(name, false, false);
  }

  /**
   * Create a {@code DelegatingGauge} with {@code perWorkerGauge} set to false.
   *
   * @param name Metric name for this metric.
   * @param processWideContainer Whether this Gauge is stored in the ProcessWide container or the
   *     current thread's container.
   */
  public DelegatingGauge(MetricName name, boolean processWideContainer) {
    this(name, processWideContainer, false);
  }

  /**
   * @param name Metric name for this metric.
   * @param processWideContainer Whether this gauge is stored in the ProcessWide container or the
   *     current thread's container.
   * @param perWorkerGauge Whether this gauge refers to a perWorker metric or not.
   */
  public DelegatingGauge(MetricName name, boolean processWideContainer, boolean perWorkerGauge) {
    this.name = name;
    this.processWideContainer = processWideContainer;
    this.perWorkerGauge = perWorkerGauge;
  }

  /** Set the gauge. */
  @Override
  public void set(long n) {
    MetricsContainer container =
        this.processWideContainer
            ? MetricsEnvironment.getProcessWideContainer()
            : MetricsEnvironment.getCurrentContainer();
    if (container == null) {
      return;
    }
    if (perWorkerGauge) {
      container.getPerWorkerGauge(name).set(n);
    } else {
      container.getGauge(name).set(n);
    }
  }

  @Override
  public MetricName getName() {
    return name;
  }
}

==> apache-beam-2.71.0-source-release.zip: beam-2.71.0/sdks/java/core/src/main/java/org/apache/beam/sdk/metrics/DelegatingGauge.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.metrics;

import java.io.Serializable;
import org.apache.beam.sdk.annotations.Internal;

/** Implementation of {@link Gauge} that delegates to the instance for the current context. */
@Internal
public class DelegatingGauge implements Metric, Gauge, Serializable {

  private final MetricName name;
  private final boolean processWideContainer;

  /**
   * Create a {@code DelegatingGauge} with {@code perWorkerGauge} and {@code processWideContainer}
   * set to false.
   *
   * @param name Metric name for this metric.
   */
  public DelegatingGauge(MetricName name) {
    this(name, false);
  }

  /**
   * @param name Metric name for this metric.
   * @param processWideContainer Whether this gauge is stored in the ProcessWide container or the
   *     current thread's container.
   */
  public DelegatingGauge(MetricName name, boolean processWideContainer) {
    this.name = name;
    this.processWideContainer = processWideContainer;
  }

  /** Set the gauge. */
  @Override
  public void set(long n) {
    MetricsContainer container =
        this.processWideContainer
            ? MetricsEnvironment.getProcessWideContainer()
            : MetricsEnvironment.getCurrentContainer();
    if (container == null) {
      return;
    }
    container.getGauge(name).set(n);
  }

  @Override
  public MetricName getName() {
    return name;
  }
}
